@@ -635,7 +635,7 @@ class Filter(JailThread):
 				e = m.end(1)
 				m = line[s:e]
 				tupleLine = (line[:s], m, line[e:])
-				if m: # found and not empty - retrive date:
+				if m: # found and not empty - retrieve date:
 					date = self.dateDetector.getTime(m, timeMatch)
 					if date is not None:
 						# Lets get the time part
@@ -666,7 +666,7 @@ class Filter(JailThread):
 		if self.checkFindTime and date is not None:
 			# if in operation (modifications have been really found):
 			if self.inOperation:
-				# if weird date - we'd simulate now for timeing issue (too large deviation from now):
+				# if weird date - we'd simulate now for timing issue (too large deviation from now):
 				delta = int(date - MyTime.time())
 				if abs(delta) > 60:
 					# log timing issue as warning once per day:
@@ -944,7 +944,7 @@ class Filter(JailThread):
 							ip = fid
 							raw = True
 				# if mlfid case (not failure):
-				if ip is None:
+				if fid is None and ip is None:
 					if ll <= 7: logSys.log(7, "No failure-id by mlfid %r in regex %s: %s",
 						mlfid, failRegexIndex, fail.get('mlfforget', "waiting for identifier"))
 					fail['mlfpending'] = 1; # mark failure is pending
@@ -978,6 +978,8 @@ class Filter(JailThread):
 	def status(self, flavor="basic"):
 		"""Status of failures detected by filter.
 		"""
+		if flavor == "stats":
+			return (self.failManager.size(), self.failManager.getFailTotal())
 		ret = [("Currently failed", self.failManager.size()),
 		       ("Total failed", self.failManager.getFailTotal())]
 		return ret
@@ -1255,6 +1257,8 @@ class FileFilter(Filter):
 		"""Status of Filter plus files being monitored.
 		"""
 		ret = super(FileFilter, self).status(flavor=flavor)
+		if flavor == "stats":
+			return ret
 		path = list(self.__logs.keys())
 		ret.append(("File list", path))
 		return ret
